==> contentsquare-1.0.1.tar.gz: test/helpers/matchers/cs_gesture_data_matcher.dart <==
import 'package:contentsquare_platform_interface/contentsquare_platform_interface.dart';
import 'package:flutter_test/flutter_test.dart';

Matcher almostEqualGesture(ContentsquareGestureData referenceGestureData) =>
    CSGestureDataMatcher(referenceGestureData);

const double _kVelocityImprecisionRange = 2.0;

/// When gestures are performed in a negative direction (down or left), the [VelocityTracker.getVelocityEstimate] (https://api.flutter.dev/flutter/gestures/VelocityTracker/getVelocityEstimate.html) method
/// uses a Least Square interpolation that computes the gesture velocity with a certain imprecision (estimating 199 for a given speed of 200).
/// Because pixel precision is not relevant when computing the velocity of the gestures,
/// we provide a custom matcher for the CSGestureData object that accepts gestures with velocity values within a given imprecision range of +/- [_kVelocityImprecisionRange]dp.
class CSGestureDataMatcher extends Matcher {
  ContentsquareGestureData referenceGestureData;
  final double _velocityImprecisionRange = _kVelocityImprecisionRange;

  CSGestureDataMatcher(this.referenceGestureData);

  bool _isVelocityWithinImprecisionRange(int velocity) {
    return velocity >
            referenceGestureData.velocity - _velocityImprecisionRange &&
        velocity < referenceGestureData.velocity + _velocityImprecisionRange;
  }

  @override
  Description describe(Description description) {
    description.add('CSGestureData with ');
    description.add('distance: ${referenceGestureData.distance}, ');
    description.add('direction: ${referenceGestureData.direction} ');
    description.add(
        'and velocity in range [${referenceGestureData.velocity - _velocityImprecisionRange}, ${referenceGestureData.velocity + _velocityImprecisionRange}]');
    return description;
  }

  @override
  bool matches(item, Map matchState) {
    final gestureData = (item as ContentsquareGestureData);
    return gestureData.distance == referenceGestureData.distance &&
        gestureData.direction == referenceGestureData.direction &&
        _isVelocityWithinImprecisionRange(gestureData.velocity);
  }
}

==> contentsquare-2.3.0.tar.gz: test/helpers/matchers/cs_gesture_data_matcher.dart <==
import 'package:contentsquare_platform_interface/contentsquare_platform_interface.dart';
import 'package:flutter_test/flutter_test.dart';

Matcher almostEqualGesture(ContentsquareGestureData referenceGestureData) =>
    CSGestureDataMatcher(referenceGestureData);

const double _kVelocityImprecisionRange = 2.0;

/// When gestures are performed in a negative direction (down or left), the
/// [VelocityTracker.getVelocityEstimate] (https://api.flutter.dev/flutter/gestures/VelocityTracker/getVelocityEstimate.html) method
/// uses a Least Square interpolation that computes the gesture velocity with a
/// certain imprecision (estimating 199 for a given speed of 200).
/// Because pixel precision is not relevant when computing the velocity of the
/// gestures, we provide a custom matcher for the CSGestureData object that
/// accepts gestures with velocity values within a given imprecision range
/// of +/- [_kVelocityImprecisionRange]dp.
class CSGestureDataMatcher extends Matcher {
  ContentsquareGestureData referenceGestureData;
  final double _velocityImprecisionRange = _kVelocityImprecisionRange;

  CSGestureDataMatcher(this.referenceGestureData);

  bool _isVelocityWithinImprecisionRange(int velocity) {
    return velocity >
            referenceGestureData.velocity - _velocityImprecisionRange &&
        velocity < referenceGestureData.velocity + _velocityImprecisionRange;
  }

  @override
  Description describe(Description description) {
    description.add('CSGestureData with ');
    description.add('distance: ${referenceGestureData.distance}, ');
    description.add('direction: ${referenceGestureData.direction} ');
    description.add(
      'and velocity in range '
      '[${referenceGestureData.velocity - _velocityImprecisionRange}, '
      '${referenceGestureData.velocity + _velocityImprecisionRange}]',
    );
    return description;
  }

  @override
  bool matches(item, Map matchState) {
    final gestureData = (item as ContentsquareGestureData);
    return gestureData.distance == referenceGestureData.distance &&
        gestureData.direction == referenceGestureData.direction &&
        _isVelocityWithinImprecisionRange(gestureData.velocity);
  }
}
